


function [z] = bigaussianpdf()
    //   Compute probability density p(x,y) at (x,y) for a bivariate Gaussian distribution.
    //
    //   Syntax
    //   z = bigaussian(mx,my,sx,sy,rho,x,y)
    //   
    //   Parameters
    //   z: output 
    //   mx: mean in the x direction.
    //   my: mean in the y direction.
    //   sx: standard deviation in the x direction.
    //   sy: standard deviation in the y direction.
    //   rho: It is the correlation coefficient and lies in between -1 and +1.
    //   x,y: correlated Gaussian variates at which probability density p(x,y) is to be computed.
    //   
    //   Description
    //   This function computes the probability density p(x,y) at (x,y) for a bivariate Gaussian distribution with mean mx,my and standard deviations sx, sy and correlation coefficient rho.
    //
    //
    // Examples 
    // // Computes the probability density p(x,y) at (1,1) for a bivariate Gaussian distribution with mean mx=0, my=0 and standard deviations sx=1, sy=1 and correlation coefficient rho=0.9.
        // mx=0
        // my=0
        // sx=1
        // sy=1
        // rho=0.9
        // x=1
        // y=1
	// z = bigaussianpdf(mx,my,sx,sy,rho,x,y)
        // disp(z)
	//
// Authors
// Dr. Rajan Goyal
// Dr. Rashmi Verma
// Ms. Sakshi Verma
// Ms. Mahiguhappriyaprakash
endfunction
