


function [y] = splfunc()
    //   It computes the value of special functions e.g. Airy's function, Gamma function, Beta function, Bessel's function, Legendre's polynomial etc.
    //
    //   Syntax
    //   y = splfunc(choice,c1,c2)
    //   
    //   Parameters
    //   y: output 
    //   c1 and c2: real or integer numbers depending on the type of special function to be evaluated.
    //   choice: It is used to choose the desired special function and is always a positive integer i.e. choice>0.
    //   choice = 1: Airy's Function Ai(x), c1 represents the x while c2 can be set to any value.
    //   choice = 2: Airy's Function Bi(x), c1 represents the x while c2 can be set to any value.
    //   choice = 3: Scaled Airy's Function Ai(x), c1 represents the x while c2 can be set to any value.
    //   choice = 4: Scaled Airy's Function Bi(x), c1 represents the x while c2 can be set to any value.
    //   choice = 5: Derivative of Airy's Function Ai(x), c1 represents the x while c2 can be set to any value.
    //   choice = 6: Derivative of Airy's Function Bi(x), c1 represents the x while c2 can be set to any value.
    //   choice = 7: Scaled Derivative of Airy's Function Ai(x), c1 represents the x while c2 can be set to any value.
    //   choice = 8: Scaled Derivative of Airy's Function Bi(x), c1 represents the x while c2 can be set to any value.
    //   Choice = 9: nth Zeros of Airy's Function Ai(x), c1 can be set to any value while c2 will be an integer representing nth zero.
    //   choice = 10: nth Zeros of Airy's Function Bi(x), c1 can be set to any value while c2 will be an integer representing nth zero.
    //   choice = 11: nth Zeros of Derivative of Airy's Function Ai(x), c1 can be set to any value while c2 will be an integer representing nth zero.
    //   choice = 12: nth Zeros of Derivative of Airy's Function Bi(x), c1 can be set to any value while c2 will be an integer representing nth zero.
    //   choice = 13: Regular Cylindrical Bessel's Function Jn(x), c1 represents x and c2 represents n. Here n is an integer.
    //   choice = 14: Iregular Cylindrical Bessel's Function Yn(x), c1 represents x, x>0 and c2 represents n. Here n is greater than equal to 0.
    //   choice = 15: Regular Modified Cylindrical Bessel's Function In(x), c1 represents x, x>0 and c2 represents n. Here n is greater than equal to 0.
    //   choice = 16: Scaled Regular Modified Cylindrical Bessel's Function In(x), c1 represents x, x>0 and c2 represents n. Here n is an integer.
    //   choice = 17: Iregular Modified Cylindrical Bessel's Function Kn(x), c1 represents x, x>0 and c2 represents n. Here n is an integer.
    //   Choice = 18: Scaled Iregular Modified Cylindrical Bessel's Function Kn(x), c1 represents x, x>0 and c2 represents n. Here n is an integer.
    //   choice = 19: Regular Spherical Bessel's Function jl(x), c1 and c2 represent x and l respectively. x is real and l is an integer. x and l both are greater than equal to zero.
    //   choice = 20: Iregular Spherical Bessel's Function yl(x), c1 and c2 represent x and l respectively. x is real and l is an integer. x and l both are greater than equal to zero.
    //   choice = 21: Scaled Regular Modified Spherical Bessel's Function il(x), c1 and c2 represent x and l respectively. x is real and l is an integer. x and l both are greater than equal to zero.
    //   choice = 22: Scaled Iregular Modified Spherical Bessel's Function kl(x), c1 and c2 represent x and l respectively. x is real and l is an integer. x and l both are greater than equal to zero.
    //   choice = 23: Regular Cylindrical Bessel's Function Jn(x), c1 represents x, x>0 and c2 represents n. Here n is a fraction.
    //   choice = 24: Irregular Cylindrical Bessel's Function Yn(x), c1 represents x, x>0 and c2 represents n. Here n is a fraction.
    //   choice = 25: Regular Modified Cylindrical Bessel's Function In(x), c1 represents x, x>0 and c2 represents n. Here n is a fraction, n>0
    //   choice = 26: Scaled Regular Modified Cylindrical Bessel's Function In(x), c1 represents x, x>0 and c2 represents n. Here n is a fraction, n>0
    //   Choice = 27: Iregular Modified Cylindrical Bessel's Function Kn(x), c1 represents x, x>0 and c2 represents n. Here n is a fraction, n>0
    //   choice = 28: Scaled Iregular Modified Cylindrical Bessel's Function Kn(x), c1 represents x, x>0 and c2 represents n. Here n is a fraction, n>0
    //   choice = 29: nth Zero of Regular Cylindrical Bessel Function J0(x), c1 can be set to any value while c2 represents n and is a positive integer.
    //   choice = 30: nth Zero of Regular Cylindrical Bessel Function J1(x), c1 can be set to any value while c2 represents n and is a positive integer.
    //   choice = 31: mth Zero of Regular Cylindrical Bessel Function Jn(x), c1 represents m while c2 represents n. Here n is a positive fraction.
    //   choice = 32: Dawson Function or Integral Da(x), c1 represents x while c2 can be set to any value.
    //   choice = 33: Debye Function or Integral of first order D1(x), c1 represents x and x>0 while c2 can be set to any value.
    //   choice = 34: Debye Function or Integral of second order D2(x), c1 represents x and x>0 while c2 can be set to any value.
    //   choice = 35: Error Function erf(x), c1 represents x and x>0 while c2 can be set to any value.
    //   Choice = 36: Complementary Error Function erfc(x), c1 represents x and x>0 while c2 can be set to any value.
    //   Choice = 37: Log Complementary Error Function erfc_ln(x), c1 represents x and x>0 while c2 can be set to any value.
    //   choice = 38: Normalized Normal or Gaussian Probability Density Function N~(0,1), c1 represents x while c2 can be set to any value.
    //   choice = 39: Upper tail Normalized Gaussian probability density function N~(0,1), c1 represents x while c2 can be set to any value.
    //   choice = 40: Real part of the Exponential Integral En(x), c1 and c2 represent x and n respectively. n is positive real number.
    //   choice = 41: Fermi Dirac Integral Fn(x), c1  represents x and x is real number while c2 represents n and n is positive integer.
    //   choice = 42: Gamma Function, c1 represents n and can be set to an integer or fraction. c1 cannot be set equal to zero and c2 can be set to any value
    //   choice = 43: Beta function, c1 and c2 represent m and n. Both m and n are positive integers.
    //   choice = 44: Laguerre Polynomial of order n Ln(x), c1 and c2 represent x and n respectively. n is a non-negative integer.
    //   choice = 45: Legendre's Polynomial of order n Pn(x), c1 and c2 represent x and n respectively. n is a non-negative integer.
    //   
    //   Description
    //   This function takes the parameters choice and two numbers to calculate the special functions.
    //
    //
    // Examples 
    // // Beta Function 
        // choice=43
        // c1=1
        // c2=2
	// y = splfunc(choice,c1,c2)
	//
// Authors
// Dr. Rajan Goyal
// Dr. Rashmi Verma
// Ms. Sakshi Verma
// Ms. Mahiguhappriyaprakash
endfunction
