
extern "C"
{
#include<Scierror.h>
#include<api_scilab.h>
#include <stdio.h>
#include <math.h>
#include "localization.h"
#include <gsl/gsl_errno.h>
#include <gsl/gsl_math.h>
#include <gsl/gsl_monte.h>
#include <gsl/gsl_monte_plain.h>
#include <gsl/gsl_monte_miser.h>
#include <gsl/gsl_monte_vegas.h>
#include <gsl/gsl_rng.h>
#include <gsl/gsl_sys.h>
#include <gsl/gsl_inline.h>
#include <gsl/gsl_machine.h>
#include <gsl/gsl_precision.h>
#include <gsl/gsl_nan.h>
#include <gsl/gsl_pow_int.h>
#include <gsl/gsl_minmax.h>
#include <gsl/gsl_types.h>
#include <gsl/gsl_sf.h>

double* in1 = NULL;
double* in2 = NULL;
double* in3 = NULL;
double
g (double *K, size_t dim, void *params)
{
  double A;
  
if (*in1==1)
{// Gamma Function
A = (pow(K[0],(*in2-1)))*exp(-K[0]) ;}
else if (*in1==2)
// Gaussian Function
{ A = 1.0 / ((sqrt(2*M_PI)*(*in3)));
  A = A*exp(-(pow((K[0]-*in2),2)) / (2*(pow(*in3,2))));}
else if (*in1==3)
// Airy's Function Ai(x)
{A = 1.0/M_PI;
A = A*cos(pow(K[0],3)/3.0+*in2*K[0]);}
else if (*in1==4)
// Airy's Function Bi(x)
{A = 1.0/M_PI;
A = A*(sin(pow(K[0],3)/3.0+*in2*K[0])+exp(-1.0*pow(K[0],3)/3.0+*in2*K[0]));
}
else if (*in1==5)
// Ellipitic Integral of First Kind
{
A=1-pow(*in2,2)*sin(K[0])*sin(K[0]);
A=sqrt(A);
A=1/A;
}

else if (*in1==6)
// Elliptic Integral of Second Kind
{
A=1-pow(*in2,2)*sin(K[0])*sin(K[0]);
A=sqrt(A);
}

else if (*in1==7)
// Beta Function
{
A=pow(K[0],(*in2-1))*pow((1-K[0]),(*in3-1));
}
else 
// Bessel Function
{
A=1.0/M_PI;
A=A*cos(*in2*K[0]-*in3*sin(K[0]));
}

return A;
}
 



static const char fname[] = "montecarlo";
double sci_montecarlo(scilabEnv env, int nin, scilabVar* in, int nopt, scilabOpt* opt, int nout, scilabVar* out)

{
	
	double* in4 = NULL;
	double* in5 = NULL;
	double* in6 = NULL;
        double* in7 = NULL;
	double* out1=NULL;

	
	
	double res, err,res1,err1;
  
if (nin != 7)
    {
        Scierror(77, _("%s: Wrong number of input argument(s): %d expected.\n"), fname, 2);
        return 1;
    }

if (nout != 1)
    {
        Scierror(77, _("%s: Wrong number of output argument(s): %d expected.\n"), fname, 1);
        return 1;
    }

    scilab_getDoubleArray(env, in[0], &in1);
    scilab_getDoubleArray(env, in[1], &in2);
    scilab_getDoubleArray(env, in[2], &in3);
    scilab_getDoubleArray(env, in[3], &in4);
    scilab_getDoubleArray(env, in[4], &in5);
    scilab_getDoubleArray(env, in[5], &in6);
    scilab_getDoubleArray(env, in[6], &in7);
   
    
    
    



 

gsl_rng *r;
gsl_rng_env_setup ();
r = gsl_rng_alloc (gsl_rng_ranlux);
gsl_monte_function G = {&g, 1, 0} ;


if(*in7==1)
{
gsl_monte_plain_state *s = gsl_monte_plain_alloc (1);
gsl_monte_plain_integrate (&G,
                           in4, in5,
                          1,
                           5*in6[0],
                            r,
                            s,
                           &res,&err);

gsl_monte_plain_free (s);

}

else if(*in7==2)
{
    gsl_monte_miser_state *s = gsl_monte_miser_alloc (1);
   gsl_monte_miser_integrate (&G,
                           in4, in5,
                          1,
                           5*in6[0],
                            r,
                            s,
                           &res,&err);
    gsl_monte_miser_free (s);

    
  }

else
{
    gsl_monte_vegas_state *s = gsl_monte_vegas_alloc (1);

     gsl_monte_vegas_integrate (&G,
                           in4, in5,
                          1,
                           5*in6[0],
                            r,
                            s,
                           &res,&err);
    

    do
      {
        gsl_monte_vegas_integrate (&G,
                           in4, in5,
                          1,
                           5*in6[0],
                            r,
                            s,
                           &res,&err);
      }
    while (fabs (gsl_monte_vegas_chisq (s) - 1.0) > 0.5);

    gsl_monte_vegas_free (s);
  }

out[0] = scilab_createDoubleMatrix2d(env, 1, 1, 0);
   	scilab_getDoubleArray(env, out[0], &out1);

out1[0] = res;


    return 0;

}
}


