
extern "C"
{
#include <Scierror.h>
#include <api_scilab.h>
#include <sciprint.h>
#include <stdio.h>
#include <math.h>
#include "localization.h"
#include <gsl/gsl_errno.h>
#include <gsl/gsl_math.h>
#include <gsl/gsl_const_mksa.h>
#include <gsl/gsl_const_num.h>






static const char fname[] = "phyconst";
double sci_phyconst(scilabEnv env, int nin, scilabVar* in, int nopt, scilabOpt* opt, int nout, scilabVar* out)

{
	
	double* in1=NULL;
	double* out1 = NULL;
       
	
	
	double res;
  
if (nin != 1)
    {
        Scierror(77, _("%s: Wrong number of input argument(s): %d expected.\n"), fname, 2);
        return 1;
    }

if (nout != 1)
    {
        Scierror(77, _("%s: Wrong number of output argument(s): %d expected.\n"), fname, 1);
        return 1;
    }

   scilab_getDoubleArray(env, in[0], &in1);
    
   if (*in1==1)
   // speed of light
   res=GSL_CONST_MKSA_SPEED_OF_LIGHT;
   else if(*in1==2) 
   // mu0
   res=GSL_CONST_MKSA_VACUUM_PERMEABILITY;
   else if(*in1==3)
   //eps0
   res=GSL_CONST_MKSA_VACUUM_PERMITTIVITY;
   else if(*in1==4)
   // h
   res=GSL_CONST_MKSA_PLANCKS_CONSTANT_H;
   else if(*in1==5)
   //hbar
   res=GSL_CONST_MKSA_PLANCKS_CONSTANT_HBAR;
   else if(*in1==6)
   //Na
   res= GSL_CONST_NUM_AVOGADRO;
   else if(*in1==7)
   //kb
   res=GSL_CONST_MKSA_BOLTZMANN;
   else if(*in1==8)
   //R0
   res=GSL_CONST_MKSA_MOLAR_GAS;
   else if(*in1==9)
   //sigma
   res=GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT;
   else if(*in1==10)
   //G
   res=GSL_CONST_MKSA_GRAVITATIONAL_CONSTANT;
   else if(*in1==11)
   //lightyear
   res=GSL_CONST_MKSA_LIGHT_YEAR;
   else if(*in1==12)
   //g
   res=  GSL_CONST_MKSA_GRAV_ACCEL;
   else if(*in1==13)
   //e
   res= GSL_CONST_MKSA_ELECTRON_CHARGE;
   else if(*in1==14)
   // mass of muon
   res=GSL_CONST_MKSA_MASS_MUON;
   else if(*in1==15)
   // mass of proton
   res=GSL_CONST_MKSA_MASS_PROTON;
   else if(*in1==16)
   // mass of neutron
   res=GSL_CONST_MKSA_MASS_NEUTRON;
   else if(*in1==17)
   // mass of electron
   res =  GSL_CONST_MKSA_MASS_ELECTRON;
   else if(*in1==18)
   // Hyperfine structure constant alpha
   res=GSL_CONST_NUM_FINE_STRUCTURE;
   else if(*in1==19)
   // Rydeberg constant
   res=GSL_CONST_MKSA_RYDBERG/(GSL_CONST_MKSA_SPEED_OF_LIGHT*GSL_CONST_MKSA_PLANCKS_CONSTANT_H);
   else if(*in1==20)
   // Bohr radius a0
   res=GSL_CONST_MKSA_BOHR_RADIUS;
   else if(*in1==21)
   //muB
   res = GSL_CONST_MKSA_BOHR_MAGNETON;
   else if(*in1==22)
   // muN
   res=GSL_CONST_MKSA_NUCLEAR_MAGNETON;
   else if(*in1==23)
   // absolute value of mue
   res=GSL_CONST_MKSA_ELECTRON_MAGNETIC_MOMENT;
   else if(*in1==24)
   // mup
   res=GSL_CONST_MKSA_PROTON_MAGNETIC_MOMENT;
   else if(*in1==25)
   // thomson cross section sigmaT
   res=GSL_CONST_MKSA_THOMSON_CROSS_SECTION;
   else
   sciprint("unkown physical constant");
   

      

    
        
	out[0] = scilab_createDoubleMatrix2d(env, 1, 1, 0);
   	scilab_getDoubleArray(env, out[0], &out1);

	out1[0] = res;
        




	return 0;
}

}

