
extern "C"
{
#include<Scierror.h>
#include<api_scilab.h>
#include <stdio.h>
#include <math.h>
#include "localization.h"
#include <gsl/gsl_errno.h>
#include <gsl/gsl_math.h>
#include <gsl/gsl_sf.h>





static const char fname[] = "splfunc";
double sci_splfunc(scilabEnv env, int nin, scilabVar* in, int nopt, scilabOpt* opt, int nout, scilabVar* out)

{
	
	double* in1 = NULL;
        double* in2 = NULL;
        double* in3 =NULL;
	double* out1 = NULL;
        gsl_sf_result* result;
	
	
	double res;
  
if (nin != 3)
    {
        Scierror(77, _("%s: Wrong number of input argument(s): %d expected.\n"), fname, 2);
        return 1;
    }

if (nout != 1)
    {
        Scierror(77, _("%s: Wrong number of output argument(s): %d expected.\n"), fname, 1);
        return 1;
    }

    scilab_getDoubleArray(env, in[0], &in1);
    scilab_getDoubleArray(env, in[1], &in2);
    scilab_getDoubleArray(env, in[2], &in3);

    if(*in1==1)
    // Airy's Function Ai(x)
    res=gsl_sf_airy_Ai(*in2,GSL_PREC_DOUBLE);
    else if(*in1==2)
    // Airy's Function Bi(x)
    res=gsl_sf_airy_Bi(*in2,GSL_PREC_DOUBLE);
    else if(*in1==3)
    // Scaled Airy's Function Ai(x)
    res=gsl_sf_airy_Ai_scaled(*in2,GSL_PREC_DOUBLE);
    else if(*in1==4)
    // Scaled Airy's Function Bi(x)
    res=gsl_sf_airy_Bi_scaled(*in2,GSL_PREC_DOUBLE); 
    else if(*in1==5)
    // Derivative of Airy's Function Ai(x)
    res=gsl_sf_airy_Ai_deriv(*in2,GSL_PREC_DOUBLE);
    else if(*in1==6)
    // Derivative Airy's Function Bi(x)
    res=gsl_sf_airy_Bi_deriv(*in2,GSL_PREC_DOUBLE);
    else if(*in1==7)
    // Scaled derivative Airy's Function Ai(x)
    res=gsl_sf_airy_Ai_deriv_scaled(*in2,GSL_PREC_DOUBLE);
    else if(*in1==8)
    // Scaled derivative Airy's Function Bi(x)
    res=gsl_sf_airy_Bi_deriv_scaled(*in2,GSL_PREC_DOUBLE); 
    else if(*in1==9)
    // Zeros of Airy's Function Ai(x)
    res=gsl_sf_airy_zero_Ai(*in3);
    else if(*in1==10)
    // Zeros of Airy's Function Bi(x)
    res=gsl_sf_airy_zero_Bi(*in3);
    else if(*in1==11)
    // Zeros of derivative of Airy's Function Ai(x)
    res=gsl_sf_airy_zero_Ai_deriv(*in3);
    else if(*in1==12)
    // Zeros of derivative of Airy's Function Bi(x)
    res=gsl_sf_airy_zero_Bi_deriv(*in3);
    else if(*in1==13)
    // regular cylindrical Bessel Function Jn(x)
    res=gsl_sf_bessel_Jn(*in3,*in2);
    else if(*in1==14)
    // irregular cylindrical Bessel Function Yn(x)
    res=gsl_sf_bessel_Yn(*in3,*in2);
    else if(*in1==15)
    // regular modified cylindrical Bessel Function In(x)
    res=gsl_sf_bessel_In(*in3,*in2);
     else if(*in1==16)
    // scaled regular modified cylindrical Bessel Function In(x)
    res=gsl_sf_bessel_In_scaled(*in3,*in2);
    else if(*in1==17)
    // irregular modified cylindrical Bessel Function Kn(x)
    res=gsl_sf_bessel_Kn(*in3,*in2);
     else if(*in1==18)
    // scaled irregular modified cylindrical Bessel Function Kn(x)
    res=gsl_sf_bessel_Kn_scaled(*in3,*in2);
    else if(*in1==19)
    // regular spherical Bessel Function jl(x)
    res=gsl_sf_bessel_jl(*in3,*in2);
    else if(*in1==20)
    // irregular spherical Bessel Function yl(x)
    res=gsl_sf_bessel_yl(*in3,*in2);
     else if(*in1==21)
    // scaled regular modified spherical Bessel Function il(x)
    res=gsl_sf_bessel_il_scaled(*in3,*in2);
     else if(*in1==22)
    // scaled irregular modified spherical Bessel Function kl(x)
    res=gsl_sf_bessel_kl_scaled(*in3,*in2);
    else if(*in1==23)
    // regular cylindrical Bessel Function: Fractional order Jnu(x)
    res=gsl_sf_bessel_Jnu(*in3,*in2);
    else if(*in1==24)
    // irregular cylindrical Bessel Function: Fractional order Ynu(x)
    res=gsl_sf_bessel_Ynu(*in3,*in2);
    else if(*in1==25)
    // regular modified cylindrical Bessel Function: Fractional order Inu(x)
    res=gsl_sf_bessel_Inu(*in3,*in2);
     else if(*in1==26)
    // scaled regular modified cylindrical Bessel Function: Fractional order Inu(x)
    res=gsl_sf_bessel_Inu_scaled(*in3,*in2);
    else if(*in1==27)
    // irregular modified cylindrical Bessel Function: Fractional order Knu(x)
    res=gsl_sf_bessel_Knu(*in3,*in2);
     else if(*in1==28)
    // scaled irregular modified cylindrical Bessel Function: Fractional order Knu(x)
    res=gsl_sf_bessel_Knu_scaled(*in3,*in2);
    else if(*in1==29)
    // nth Zero of the regular cylindrical Bessel Function J0(x)
    res=gsl_sf_bessel_zero_J0(*in3);
    else if(*in1==30)
    // nth Zero of the regular cylindrical Bessel Function J1(x)
    res=gsl_sf_bessel_zero_J1(*in3);
    else if(*in1==31)
    // nth zero of regular cylindrical Bessel Function: Fractional order Jnu(x)
    res=gsl_sf_bessel_zero_Jnu(*in3,*in2);
    else if(*in1==32)
    // Dawson Function or Dawson Integral
    res=gsl_sf_dawson(*in2);
    else if(*in1==33)
    // Debye Function or  Integral of 1st order
    res=gsl_sf_debye_1(*in2);
    else if(*in1==34)
    // Debye Function or  Integral of 2nd order
    res=gsl_sf_debye_2(*in2);
    else if(*in1==35)
    // error function
    res=gsl_sf_erf(*in2);
    else if(*in1==36)
    // Complementary error function
    res=gsl_sf_erfc(*in2);
    else if(*in1==37)
    // log Complementary error function
    res=gsl_sf_log_erfc(*in2);
    else if(*in1==38)
    // Nomralized Gaussian probability density function
    res=gsl_sf_erf_Z(*in2);
    else if(*in1==39)
    // Upper tail Nomralized Gaussian probability density function
    res=gsl_sf_erf_Q(*in2);
    else if(*in1==40)
    // Exponential Integral
    res=gsl_sf_expint_En(*in3,*in2);
    else if(*in1==41)
    // Fermi Dirac Integral with integer index
    res=gsl_sf_fermi_dirac_int(*in3,*in2);
     else if(*in1==42)
    // Gamma Function
    res=gsl_sf_gamma(*in2);
     else if(*in1==43)
    // Beta Function
    res=gsl_sf_beta(*in2,*in3);
     else if(*in1==44)
    //  Laguerre Polynomial of order n
    res=gsl_sf_laguerre_n(*in3,0,*in2);
    else if(*in1==45)
    // Legendre Polynomial of order l
    res=gsl_sf_legendre_Pl(*in3,*in2);
    else
    {
        Scierror(77, _("%s: Wrong input of choice: %d expected.\n"), fname, 1);
        return 1;
    }


    
    
    
	out[0] = scilab_createDoubleMatrix2d(env, 1, 1, 0);
   	scilab_getDoubleArray(env, out[0], &out1);

	out1[0] = res;



    return 0;
}

}

